package hdm.mi.growbros.models.plant;

import jakarta.persistence.*;
import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.URL;
//careful! weeks are indexed at 0 -> max value is 51.

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Entity
public class Plant {
    @Id
    @GeneratedValue
    private Long id;

    @NotBlank
    @Column(unique = true)
    private String name;

    private String latinName;

    @Column(columnDefinition = "TEXT")
    private String description;

    @Column(columnDefinition = "TEXT")
    private String origin;

    @Column(columnDefinition = "TEXT")
    private String growingTips;

    @Min(0)
    @Max(51)
    private int plantWeekStart;

    @Min(0)
    @Max(51)
    private int plantWeekEnd;

    @Min(0)
    private int growthDuration;

    @Min(0)
    @Max(51)
    private int harvestWeekStart;

    @Min(0)
    @Max(51)
    private int harvestWeekEnd;

    @Enumerated(EnumType.STRING)
    private GroundType groundType;

    @Enumerated(EnumType.STRING)
    private NutrientDemand nutrientDemand;

    @Enumerated(EnumType.STRING)
    private WaterDemand waterDemand;

    @Enumerated(EnumType.STRING)
    private LightingDemand lightingDemand;

    @URL
    private String imageUrl;
}
